# coding: utf-8

"""
    decentro-in-kyc

    KYC & Onboarding

    The version of the OpenAPI document: 1.0.0
    Contact: admin@decentro.tech
    Created by: https://decentro.tech
"""

from decentro_in_kyc_client.paths.v2_kyc_forensics_image_quality.post import CheckImageQuality
from decentro_in_kyc_client.paths.v2_kyc_forensics_photocopy_check.post import CheckPhotocopy
from decentro_in_kyc_client.paths.v2_kyc_forensics_video_liveness.post import CheckVideoLiveness
from decentro_in_kyc_client.paths.v2_kyc_document_classification.post import ClassifyDocument
from decentro_in_kyc_client.paths.kyc_scan_extract_ocr.post import ExtractText
from decentro_in_kyc_client.paths.v2_kyc_identities_mask_aadhaar_uid.post import MaskAadhaarUid
from decentro_in_kyc_client.paths.v2_kyc_forensics_face_match.post import MatchFace
from decentro_in_kyc_client.paths.kyc_public_registry_validate.post import Validate


class KYCApi(
    CheckImageQuality,
    CheckPhotocopy,
    CheckVideoLiveness,
    ClassifyDocument,
    ExtractText,
    MaskAadhaarUid,
    MatchFace,
    Validate,
):
    """NOTE: This class is auto generated by Konfig
    Ref: https://konfgithis.com

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    decentro-in-kyc

    KYC & Onboarding

    The version of the OpenAPI document: 1.0.0
    Contact: admin@decentro.tech
    Created by: https://decentro.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from decentro_in_kyc_client import schemas  # noqa: F401


class ExtractTextResponse(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by Konfig.
    Ref: https://konfigthis.com

    Do not edit the class manually.
    """


    class MetaOapg:
        
        class properties:
            ocrStatus = schemas.StrSchema
            status = schemas.StrSchema
            message = schemas.StrSchema
            
            
            class ocrResult(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    
                    class properties:
                        cardNo = schemas.StrSchema
                        dateInfo = schemas.StrSchema
                        dateType = schemas.StrSchema
                        fatherName = schemas.StrSchema
                        name = schemas.StrSchema
                        gender = schemas.StrSchema
                        vid = schemas.StrSchema
                        address = schemas.StrSchema
                        sonOf = schemas.StrSchema
                        husbandOf = schemas.StrSchema
                        __annotations__ = {
                            "cardNo": cardNo,
                            "dateInfo": dateInfo,
                            "dateType": dateType,
                            "fatherName": fatherName,
                            "name": name,
                            "gender": gender,
                            "vid": vid,
                            "address": address,
                            "sonOf": sonOf,
                            "husbandOf": husbandOf,
                        }
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["cardNo"]) -> MetaOapg.properties.cardNo: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["dateInfo"]) -> MetaOapg.properties.dateInfo: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["dateType"]) -> MetaOapg.properties.dateType: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["fatherName"]) -> MetaOapg.properties.fatherName: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["gender"]) -> MetaOapg.properties.gender: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["vid"]) -> MetaOapg.properties.vid: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["address"]) -> MetaOapg.properties.address: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["sonOf"]) -> MetaOapg.properties.sonOf: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["husbandOf"]) -> MetaOapg.properties.husbandOf: ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["cardNo", "dateInfo", "dateType", "fatherName", "name", "gender", "vid", "address", "sonOf", "husbandOf", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["cardNo"]) -> typing.Union[MetaOapg.properties.cardNo, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["dateInfo"]) -> typing.Union[MetaOapg.properties.dateInfo, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["dateType"]) -> typing.Union[MetaOapg.properties.dateType, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["fatherName"]) -> typing.Union[MetaOapg.properties.fatherName, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> typing.Union[MetaOapg.properties.name, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["gender"]) -> typing.Union[MetaOapg.properties.gender, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["vid"]) -> typing.Union[MetaOapg.properties.vid, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["address"]) -> typing.Union[MetaOapg.properties.address, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["sonOf"]) -> typing.Union[MetaOapg.properties.sonOf, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["husbandOf"]) -> typing.Union[MetaOapg.properties.husbandOf, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["cardNo", "dateInfo", "dateType", "fatherName", "name", "gender", "vid", "address", "sonOf", "husbandOf", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, ],
                    cardNo: typing.Union[MetaOapg.properties.cardNo, str, schemas.Unset] = schemas.unset,
                    dateInfo: typing.Union[MetaOapg.properties.dateInfo, str, schemas.Unset] = schemas.unset,
                    dateType: typing.Union[MetaOapg.properties.dateType, str, schemas.Unset] = schemas.unset,
                    fatherName: typing.Union[MetaOapg.properties.fatherName, str, schemas.Unset] = schemas.unset,
                    name: typing.Union[MetaOapg.properties.name, str, schemas.Unset] = schemas.unset,
                    gender: typing.Union[MetaOapg.properties.gender, str, schemas.Unset] = schemas.unset,
                    vid: typing.Union[MetaOapg.properties.vid, str, schemas.Unset] = schemas.unset,
                    address: typing.Union[MetaOapg.properties.address, str, schemas.Unset] = schemas.unset,
                    sonOf: typing.Union[MetaOapg.properties.sonOf, str, schemas.Unset] = schemas.unset,
                    husbandOf: typing.Union[MetaOapg.properties.husbandOf, str, schemas.Unset] = schemas.unset,
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'ocrResult':
                    return super().__new__(
                        cls,
                        *args,
                        cardNo=cardNo,
                        dateInfo=dateInfo,
                        dateType=dateType,
                        fatherName=fatherName,
                        name=name,
                        gender=gender,
                        vid=vid,
                        address=address,
                        sonOf=sonOf,
                        husbandOf=husbandOf,
                        _configuration=_configuration,
                        **kwargs,
                    )
            responseCode = schemas.StrSchema
            requestTimestamp = schemas.StrSchema
            responseTimestamp = schemas.StrSchema
            decentroTxnId = schemas.StrSchema
            __annotations__ = {
                "ocrStatus": ocrStatus,
                "status": status,
                "message": message,
                "ocrResult": ocrResult,
                "responseCode": responseCode,
                "requestTimestamp": requestTimestamp,
                "responseTimestamp": responseTimestamp,
                "decentroTxnId": decentroTxnId,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["ocrStatus"]) -> MetaOapg.properties.ocrStatus: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["message"]) -> MetaOapg.properties.message: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["ocrResult"]) -> MetaOapg.properties.ocrResult: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["responseCode"]) -> MetaOapg.properties.responseCode: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["requestTimestamp"]) -> MetaOapg.properties.requestTimestamp: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["responseTimestamp"]) -> MetaOapg.properties.responseTimestamp: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["decentroTxnId"]) -> MetaOapg.properties.decentroTxnId: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["ocrStatus", "status", "message", "ocrResult", "responseCode", "requestTimestamp", "responseTimestamp", "decentroTxnId", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["ocrStatus"]) -> typing.Union[MetaOapg.properties.ocrStatus, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> typing.Union[MetaOapg.properties.status, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["message"]) -> typing.Union[MetaOapg.properties.message, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["ocrResult"]) -> typing.Union[MetaOapg.properties.ocrResult, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["responseCode"]) -> typing.Union[MetaOapg.properties.responseCode, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["requestTimestamp"]) -> typing.Union[MetaOapg.properties.requestTimestamp, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["responseTimestamp"]) -> typing.Union[MetaOapg.properties.responseTimestamp, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["decentroTxnId"]) -> typing.Union[MetaOapg.properties.decentroTxnId, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["ocrStatus", "status", "message", "ocrResult", "responseCode", "requestTimestamp", "responseTimestamp", "decentroTxnId", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        ocrStatus: typing.Union[MetaOapg.properties.ocrStatus, str, schemas.Unset] = schemas.unset,
        status: typing.Union[MetaOapg.properties.status, str, schemas.Unset] = schemas.unset,
        message: typing.Union[MetaOapg.properties.message, str, schemas.Unset] = schemas.unset,
        ocrResult: typing.Union[MetaOapg.properties.ocrResult, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        responseCode: typing.Union[MetaOapg.properties.responseCode, str, schemas.Unset] = schemas.unset,
        requestTimestamp: typing.Union[MetaOapg.properties.requestTimestamp, str, schemas.Unset] = schemas.unset,
        responseTimestamp: typing.Union[MetaOapg.properties.responseTimestamp, str, schemas.Unset] = schemas.unset,
        decentroTxnId: typing.Union[MetaOapg.properties.decentroTxnId, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'ExtractTextResponse':
        return super().__new__(
            cls,
            *args,
            ocrStatus=ocrStatus,
            status=status,
            message=message,
            ocrResult=ocrResult,
            responseCode=responseCode,
            requestTimestamp=requestTimestamp,
            responseTimestamp=responseTimestamp,
            decentroTxnId=decentroTxnId,
            _configuration=_configuration,
            **kwargs,
        )



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from decentro_in_kyc_client.paths.kyc_scan_extract_ocr import Api

from decentro_in_kyc_client.paths import PathValues

path = PathValues.KYC_SCAN_EXTRACT_OCR


# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from decentro_in_kyc_client.apis.path_to_api import path_to_api

import enum


class PathValues(str, enum.Enum):
    V2_KYC_IDENTITIES_MASK_AADHAAR_UID = "/v2/kyc/identities/mask_aadhaar_uid"
    V2_KYC_FORENSICS_IMAGE_QUALITY = "/v2/kyc/forensics/image_quality"
    V2_KYC_FORENSICS_FACE_MATCH = "/v2/kyc/forensics/face_match"
    V2_KYC_DOCUMENT_CLASSIFICATION = "/v2/kyc/document_classification"
    V2_KYC_FORENSICS_PHOTOCOPY_CHECK = "/v2/kyc/forensics/photocopy_check"
    KYC_SCAN_EXTRACT_OCR = "/kyc/scan_extract/ocr"
    KYC_PUBLIC_REGISTRY_VALIDATE = "/kyc/public_registry/validate"
    V2_KYC_FORENSICS_VIDEO_LIVENESS = "/v2/kyc/forensics/video_liveness"



# coding: utf-8

"""
    decentro-in-kyc

    KYC & Onboarding

    The version of the OpenAPI document: 1.0.0
    Contact: admin@decentro.tech
    Created by: https://decentro.tech
"""

from setuptools import setup, find_packages  # noqa: H301

NAME = "decentro-in-kyc-python-sdk"
VERSION = "4.1.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

# read the contents of README file
from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

REQUIRES = [
    "certifi >= 2022.12.7",
    "frozendict ~= 2.3.4",
    "python-dateutil ~= 2.7.0",
    "setuptools >= 21.0.0",
    "typing_extensions ~= 4.3.0",
    "urllib3 ~= 1.26.7",
    "validators ~= 0.20.0",]

setup(
    name=NAME,
    version=VERSION,
    description="decentro-in-kyc",
    author="Decentro",
    author_email="admin@decentro.tech",
    url="https://github.com/decentro-in/decentro-in-kyc-sdk/tree/master/python",
    keywords=["OpenAPI", "Konfig", "decentro-in-kyc"],
    python_requires=">=3.7",
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description=long_description,
    long_description_content_type='text/markdown'
)



from dataclasses import dataclass
from urllib3._collections import HTTPHeaderDict
import urllib3
import typing

@dataclass
class ApiResponse:
    headers: HTTPHeaderDict
    status: int
    response: urllib3.HTTPResponse
    round_trip_time: int
    body: typing.Any


import typing_extensions

from decentro_in_kyc_client.paths import PathValues
from decentro_in_kyc_client.apis.paths.v2_kyc_identities_mask_aadhaar_uid import V2KycIdentitiesMaskAadhaarUid
from decentro_in_kyc_client.apis.paths.v2_kyc_forensics_image_quality import V2KycForensicsImageQuality
from decentro_in_kyc_client.apis.paths.v2_kyc_forensics_face_match import V2KycForensicsFaceMatch
from decentro_in_kyc_client.apis.paths.v2_kyc_document_classification import V2KycDocumentClassification
from decentro_in_kyc_client.apis.paths.v2_kyc_forensics_photocopy_check import V2KycForensicsPhotocopyCheck
from decentro_in_kyc_client.apis.paths.kyc_scan_extract_ocr import KycScanExtractOcr
from decentro_in_kyc_client.apis.paths.kyc_public_registry_validate import KycPublicRegistryValidate
from decentro_in_kyc_client.apis.paths.v2_kyc_forensics_video_liveness import V2KycForensicsVideoLiveness

PathToApi = typing_extensions.TypedDict(
    'PathToApi',
    {
        PathValues.V2_KYC_IDENTITIES_MASK_AADHAAR_UID: V2KycIdentitiesMaskAadhaarUid,
        PathValues.V2_KYC_FORENSICS_IMAGE_QUALITY: V2KycForensicsImageQuality,
        PathValues.V2_KYC_FORENSICS_FACE_MATCH: V2KycForensicsFaceMatch,
        PathValues.V2_KYC_DOCUMENT_CLASSIFICATION: V2KycDocumentClassification,
        PathValues.V2_KYC_FORENSICS_PHOTOCOPY_CHECK: V2KycForensicsPhotocopyCheck,
        PathValues.KYC_SCAN_EXTRACT_OCR: KycScanExtractOcr,
        PathValues.KYC_PUBLIC_REGISTRY_VALIDATE: KycPublicRegistryValidate,
        PathValues.V2_KYC_FORENSICS_VIDEO_LIVENESS: V2KycForensicsVideoLiveness,
    }
)

path_to_api = PathToApi(
    {
        PathValues.V2_KYC_IDENTITIES_MASK_AADHAAR_UID: V2KycIdentitiesMaskAadhaarUid,
        PathValues.V2_KYC_FORENSICS_IMAGE_QUALITY: V2KycForensicsImageQuality,
        PathValues.V2_KYC_FORENSICS_FACE_MATCH: V2KycForensicsFaceMatch,
        PathValues.V2_KYC_DOCUMENT_CLASSIFICATION: V2KycDocumentClassification,
        PathValues.V2_KYC_FORENSICS_PHOTOCOPY_CHECK: V2KycForensicsPhotocopyCheck,
        PathValues.KYC_SCAN_EXTRACT_OCR: KycScanExtractOcr,
        PathValues.KYC_PUBLIC_REGISTRY_VALIDATE: KycPublicRegistryValidate,
        PathValues.V2_KYC_FORENSICS_VIDEO_LIVENESS: V2KycForensicsVideoLiveness,
    }
)



"""
    decentro-in-kyc

    KYC & Onboarding  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://konfigthis.com
"""


import unittest

import os
import uuid
import time

from decentro_in_kyc_client import Decentro
from decentro_in_kyc_client.exceptions import ApiException, MissingRequiredParametersError, ClientConfigurationError, SchemaValidationError, InvalidHostConfigurationError


class TestKYCApi(unittest.TestCase):
    """KYCApi unit test stubs"""

    # Just to keep things DRY
    consent_purpose = "Testing Python SDK - Konfig"
    dir = os.path.dirname(__file__)

    def setUp(self):
        self.api = Decentro(
            client_id=os.environ["DECENTRO_CLIENT_ID"],
            client_secret=os.environ["DECENTRO_CLIENT_SECRET"],
            module_secret=os.environ["DECENTRO_MODULE_SECRET"]
        ).kyc

    def tearDown(self):
        pass

    def test_missing_credentials_raises_Error(self):
        self.assertRaises(ClientConfigurationError, lambda: Decentro(
            client_secret=os.environ["DECENTRO_CLIENT_SECRET"],
            module_secret=os.environ["DECENTRO_MODULE_SECRET"]
        ))
        self.assertRaises(ClientConfigurationError, lambda: Decentro(
            client_id=os.environ["DECENTRO_CLIENT_ID"],
            module_secret=os.environ["DECENTRO_MODULE_SECRET"]
        ))
        self.assertRaises(ClientConfigurationError, lambda: Decentro(
            client_id=os.environ["DECENTRO_CLIENT_ID"],
            client_secret=os.environ["DECENTRO_CLIENT_SECRET"],
        ))

    def test_check_image_quality(self):
        """Test case for check_image_quality

        Image Quality Check  # noqa: E501
        """

        """
        Invalid type for variable 'score'. Required value type is int and passed
        type was float at
        ['received_data']['data']['image_quality']['quality_scores']['text_quality']['score']
        """
        image = open(os.path.join(self.dir, 'test_kyc_api/randomImage.jpg'), 'rb')
        response = self.api.check_image_quality(body={
            "consent": True, "consent_purpose": self.consent_purpose, "reference_id": str(uuid.uuid4()), "image": image})
        assert response is not None, "Response is null"

    def test_check_photocopy(self):
        """Test case for check_photocopy

        Photocopy Check  # noqa: E501
        """
        image = open(os.path.join(self.dir, 'test_kyc_api/randomImage.jpg'), 'rb')
        response = self.api.check_photocopy(body={
            "consent":True, "consent_purpose":self.consent_purpose, "reference_id":str(uuid.uuid4()), "image":image})
        assert response is not None, "Response is null"

    def test_check_video_liveness(self):
        """Test case for check_video_liveness

        Liveness Check  # noqa: E501
        """
        video = open(os.path.join(self.dir, 'test_kyc_api/video-5-seconds.mp4'), 'rb')
        response = self.api.check_video_liveness(body={
            "consent":"Y", "consent_purpose":self.consent_purpose, "reference_id":str(uuid.uuid4()), "video":video})
        assert response is not None, "Response is null"

        video = open(os.path.join(self.dir, 'test_kyc_api/video-11-seconds.webm'), 'rb')
        self.assertRaises(ApiException, lambda: self.api.check_video_liveness(body={
            "consent":"Y", "consent_purpose":self.consent_purpose, "reference_id":str(uuid.uuid4()), "video":video}))

    def test_classify_document(self):
        """Test case for classify_document

        ID Classification  # noqa: E501
        """
        document = open(os.path.join(self.dir, 'test_kyc_api/sampleAadhaar.jpeg'), 'rb')
        response = self.api.classify_document(body={
            "consent":True, "consent_purpose":self.consent_purpose, "reference_id":str(uuid.uuid4()), "document":document, "document_type":"Aadhaar"})
        assert response is not None, "Response is null"

        document = open(os.path.join(self.dir, 'test_kyc_api/sampleDL.jpeg'), 'rb')
        response = self.api.classify_document(body={
            "consent":True, "consent_purpose":self.consent_purpose, "reference_id":str(uuid.uuid4()), "document":document, "document_type":"Driving_License"})
        assert response is not None, "Response is null"

        document = open(os.path.join(self.dir, 'test_kyc_api/samplePAN.jpeg'), 'rb')
        response = self.api.classify_document(body={
            "consent":True, "consent_purpose":self.consent_purpose, "reference_id":str(uuid.uuid4()), "document":document, "document_type":"pan"})
        assert response is not None, "Response is null"

        document = open(os.path.join(self.dir, 'test_kyc_api/samplePassport.jpeg'), 'rb')
        response = self.api.classify_document(body={
            "consent":True, "consent_purpose":self.consent_purpose, "reference_id":str(uuid.uuid4()), "document":document, "document_type":"Passport"})
        assert response is not None, "Response is null"

        document = open(os.path.join(self.dir, 'test_kyc_api/sampleVoterID.png'), 'rb')
        response = self.api.classify_document(body={
            "consent":True, "consent_purpose":self.consent_purpose, "reference_id":str(uuid.uuid4()), "document":document, "document_type":"Voterid"})
        assert response is not None, "Response is null"

    def test_extract_text(self):
        """Test case for extract_text

        Scan & Extract  # noqa: E501
        """
        document = open(os.path.join(self.dir, 'test_kyc_api/sampleAadhaar.jpeg'), 'rb')
        response = self.api.extract_text(body={
            "consent":"Y", "consent_purpose":self.consent_purpose, "reference_id":str( uuid.uuid4()), "document_type":"Aadhaar", "document":document, "kyc_validate":1})
        assert response is not None, "Response is null"

    def test_mask_aadhaar_uid(self):
        """Test case for mask_aadhaar_uid

        Aadhaar Masking  # noqa: E501
        """
        image = open(os.path.join(self.dir, 'test_kyc_api/sampleAadhaar.jpeg'), 'rb')
        response = self.api.mask_aadhaar_uid(body={
            "consent":True, "consent_purpose":self.consent_purpose, "reference_id":str(uuid.uuid4()), "image":image})
        assert response is not None, "Response is null"

    def test_match_face(self):
        """Test case for match_face

        Face Match  # noqa: E501
        """
        image1 = open(os.path.join(self.dir, 'test_kyc_api/selfie1.jpg'), 'rb')
        image2 = open(os.path.join(self.dir, 'test_kyc_api/selfie2.jpg'), 'rb')
        response = self.api.match_face(body={
            "consent":'Y', "consent_purpose":self.consent_purpose, "reference_id":str( uuid.uuid4()), "image1":image1, "image2":image2})
        assert response is not None, "Response is null"

    def test_validate_invalid_document_type_raises_error(self):
        """Test case for validate

        Invalid Validate 
        """
        self.assertRaises(ApiException, lambda: self.api.validate(body={
            "reference_id":str(uuid.uuid4()), "consent":"Y", "consent_purpose":self.consent_purpose, "document_type":"Some invalid type", "id_number":"UP28A0008214"}
        ))

    def test_validate_missing_required_field_raises_error(self):
        """Test case for validate

        Missing required field
        """
        with self.assertRaises(MissingRequiredParametersError) as cm:
            self.api.validate(body={
                "reference_id":str(uuid.uuid4()), "consent":"Y", "document_type":"Some invalid type", "id_number":"UP28A0008214"}
            )
        self.assertEquals(str(cm.exception), "Missing 1 required parameter: 'consent_purpose'")
        with self.assertRaises(MissingRequiredParametersError) as cm:
            self.api.validate(body={
                "reference_id":str(uuid.uuid4()), "document_type":"Some invalid type", "id_number":"UP28A0008214"}
            )
        self.assertEquals(str(cm.exception), "Missing 2 required parameters: 'consent' and 'consent_purpose'")

    def test_validate_empty_required_field_raises_error(self):
        """Test case for validate

        Empty required field
        """
        with self.assertRaises(SchemaValidationError) as cm:
            self.api.validate(body={
                "reference_id": str(uuid.uuid4()), "consent": "Y", "consent_purpose": "", "document_type": "Some invalid type", "id_number": "UP28A0008214"}
            )
        self.assertEquals(str(cm.exception), '1 invalid argument. Invalid value ``, length must be greater than or equal to `1` at "consent_purpose"')
        # Test stripping of required properties
        with self.assertRaises(SchemaValidationError) as cm:
            self.api.validate(body={
                "reference_id": str(uuid.uuid4()), "consent": "Y", "consent_purpose": " ", "document_type": "Some invalid type", "id_number": "UP28A0008214"}
            )
        self.assertEquals(str(cm.exception), '1 invalid argument. Invalid value ``, length must be greater than or equal to `1` at "consent_purpose"')
    
    def test_trailing_slash_is_removed_from_host(self):
        api = Decentro(
            host="https://example.com/",
            client_id=os.environ["DECENTRO_CLIENT_ID"],
            client_secret=os.environ["DECENTRO_CLIENT_SECRET"],
            module_secret=os.environ["DECENTRO_MODULE_SECRET"]
        )
        self.assertEquals(api.kyc.api_client.configuration.host, "https://example.com")
    
    def test_invalid_host_raises_error(self):
        valid_test_cases = [
            "https://www.example.com/",
            "https://www.example.com/path/to/resource",
            "http://localhost:8000/",
            "https://127.0.0.1/",
        ]

        invalid_test_cases = [
            ("www.example.com", 'Invalid host: "www.example.com", scheme must be "http" or "https"'),
            ("https://www.example.com:", 'Invalid host: "https://www.example.com:", invalid url'),
            ("https://www.example.com/path/to/resource?param1=value1&param2=value2", 'Invalid host: "https://www.example.com/path/to/resource?param1=value1&param2=value2", query string is not allowed'),
            ("https://www.example.com/path/to/resource#fragment", 'Invalid host: "https://www.example.com/path/to/resource#fragment", fragment is not allowed'),
            ("ftp://www.example.com/", 'Invalid host: "ftp://www.example.com/", scheme must be "http" or "https"'),
            ("https://www.ex*mple.com/", 'Invalid host: "https://www.ex*mple.com/", invalid url'),
            ("https://www.example.com/path/to/ resou rce", 'Invalid host: "https://www.example.com/path/to/ resou rce", invalid url'),
            ("https://www.example.com/ path/to/resource", 'Invalid host: "https://www.example.com/ path/to/resource", invalid url'),
        ]

        for valid_url in valid_test_cases:
            Decentro(
                host=valid_url,
                client_id=os.environ["DECENTRO_CLIENT_ID"],
                client_secret=os.environ["DECENTRO_CLIENT_SECRET"],
                module_secret=os.environ["DECENTRO_MODULE_SECRET"]
            )
        for invalid_url, msg in invalid_test_cases:
            with self.assertRaises(InvalidHostConfigurationError) as cm:
                Decentro(
                    host=invalid_url,
                    client_id=os.environ["DECENTRO_CLIENT_ID"],
                    client_secret=os.environ["DECENTRO_CLIENT_SECRET"],
                    module_secret=os.environ["DECENTRO_MODULE_SECRET"]
                )
            self.assertEqual(str(cm.exception), msg)

    def test_validate_incorrect_data_type_and_value_raises_error(self):
        """Test case for validate

        Incorrect data types field
        """
        with self.assertRaises(SchemaValidationError) as cm:
            self.api.validate(body={
                "reference_id": str(uuid.uuid4()),
                "consent": True, # invalid data type
                "consent_purpose": " ", # invalid value
                "document_type": "Some invalid type",
                "id_number": "UP28A0008214"
            })
        self.assertEquals(str(cm.exception), '2 invalid arguments. Got BoolClass(True) for required type str at "consent". Invalid value ``, length must be greater than or equal to `1` at "consent_purpose"')

    def test_validate_multiple_incorrect_data_type_raises_error(self):
        """Test case for validate

        Incorrect data types field
        """
        with self.assertRaises(SchemaValidationError) as cm:
            self.api.validate(body={
                "reference_id": str(uuid.uuid4()),
                "consent": True, # invalid data type
                "consent_purpose": 1, # invalid data type
                "document_type": "Some invalid type",
                "id_number": "UP28A0008214"
            })
        self.assertEquals(str(cm.exception), '2 invalid arguments. Got BoolClass(True) for required type str at "consent". Got Decimal(1) for required type str at "consent_purpose"')
        

    def test_validate_valid(self):
        """Test case for validate

        Validate  # noqa: E501
        """

        response = self.api.validate(body={
            "reference_id":str(time.time_ns()),
            "consent":"Y",
            "consent_purpose":self.consent_purpose,
            "document_type": "Udyog_Aadhaar",
            "id_number": "UP28A0008214"
        })
        assert response is not None, "Response is null"
        assert response.round_trip_time is not None, "Round trip time exists"
        assert response.body['kycStatus'] == "SUCCESS", "Status is successful"
        assert response.body['kycResult']['status'] == "ACTIVE", "Result is active"

        response = self.api.validate(body={
            "reference_id":str(time.time_ns()),
            "consent":"Y",
            "consent_purpose":self.consent_purpose,
            "document_type":"FSSAI",
            "id_number":"20821012000345"
        })
        assert response is not None, "Response is null"

        response = self.api.validate(body={
            "reference_id":str(time.time_ns()),
            "consent":"Y",
            "consent_purpose":self.consent_purpose,
            "document_type":"PAN",
            "id_number":"BDAPC9977L"
        })
        assert response is not None, "Response is null"

        response = self.api.validate(body={
            "reference_id":str(time.time_ns()),
            "consent":"Y",
            "consent_purpose":self.consent_purpose,
            "document_type":"VoterID",
            "id_number":"KJC7967979"
        })
        assert response is not None, "Response is null"

        response = self.api.validate(body={
            "reference_id":str(time.time_ns()),
            "consent":"Y",
            "consent_purpose":self.consent_purpose,
            "document_type":"CIN",
            "id_number":"U67190TN2014PTC096978"
        })
        assert response is not None, "Response is null"

        response = self.api.validate(body={
            "reference_id":str(time.time_ns()),
            "consent":"Y",
            "consent_purpose":self.consent_purpose,
            "document_type":"GSTIN",
            "id_number":"26AAACP3812E1ZV"
        })
        assert response is not None, "Response is null"

        """
        HTTP response body: {"status": "SUCCESS", "kycStatus": "UNKNOWN",
        "error": {"message": "No records found for the given ID.",
        "responseCode": "E00026"}, "requestTimestamp": "2023-01-27
        15:23:28.321986 IST (GMT +0530)", "responseTimestamp": "2023-01-27
        15:23:37.282835 IST (GMT +0530)", "decentroTxnId":
        "6A7E6B2A792049E389F642881536E16E"}
        """
        response = self.api.validate(body={
            "reference_id":str(time.time_ns()),
            "consent":"Y",
            "consent_purpose":self.consent_purpose,
            "document_type":"Driving_License",
            "id_number":"GJ0119960040773",
            "dob":"1996-08-13"
        })
        assert response is not None, "Response is null"

        """
        HTTP response body: {"status": "FAILURE", "kycStatus": "UNKNOWN",
        "error": {"message": "Name is mandatory when verifying passport. Hint:
        name (string).", "responseCode": "E00009"}, "requestTimestamp":
        "2023-01-27 15:20:23.805948 IST (GMT +0530)", "responseTimestamp":
        "2023-01-27 15:20:23.817793 IST (GMT +0530)", "decentroTxnId":
        "2E0CE8C0F0FC43F3B4B741B0F8DAE1BA"}
        """
        """
        {"status": "FAILURE", "kycStatus": "UNKNOWN", "error": {"message": "File
        number provided is not valid, It should be exactly of 15 characters
        long. Hint: id_number (string).", "responseCode": "E00009"},
        "requestTimestamp": "2023-02-01 14:33:34.057365 IST (GMT +0530)",
        "responseTimestamp": "2023-02-01 14:33:34.072897 IST (GMT +0530)",
        "decentroTxnId": "7CE473DD50664223A29FD44A768BB948"}
        """
        response = self.api.validate(body={
            "reference_id":str(time.time_ns()),
            "consent":"Y",
            "consent_purpose":self.consent_purpose,
            "document_type":"Passport",
            "id_number":"8707305F2709042",
            "name":"J8369854",
            "dob":"1996-08-13"
        })
        assert response is not None, "Response is null"

        """
        HTTP response body: {"status": "FAILURE", "kycStatus": "UNKNOWN",
        "error": {"message": "Internal Server Error. Please try again after
        sometime. If the problem persists, please drop a mail to
        support@decentro.tech.", "responseCode": "E00000"}, "requestTimestamp":
        "2023-01-27 15:21:50.958320 IST (GMT +0530)", "responseTimestamp":
        "2023-01-27 15:21:53.614626 IST (GMT +0530)", "decentroTxnId":
        "C623B47AF92E4A4DB0E3E32D8B5B9F1A"}
        """
        response = self.api.validate(body={
            "reference_id":str(time.time_ns()),
            "consent":"Y",
            "consent_purpose":self.consent_purpose,
            "document_type":"RC",
            "id_number":"TN72AS0765"
        })
        assert response is not None, "Response is null"


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    decentro-in-kyc

    KYC & Onboarding

    The version of the OpenAPI document: 1.0.0
    Contact: admin@decentro.tech
    Created by: https://decentro.tech
"""

__version__ = "4.1.0"

# import ApiClient
from decentro_in_kyc_client.api_client import ApiClient

# import Configuration
from decentro_in_kyc_client.configuration import Configuration

# import exceptions
from decentro_in_kyc_client.exceptions import OpenApiException
from decentro_in_kyc_client.exceptions import ApiAttributeError
from decentro_in_kyc_client.exceptions import ApiTypeError
from decentro_in_kyc_client.exceptions import ApiValueError
from decentro_in_kyc_client.exceptions import ApiKeyError
from decentro_in_kyc_client.exceptions import ApiException

from decentro_in_kyc_client.client import Decentro
